Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// MinVersionSFGA sets minimal version of SFGA archive schema
// that is needed for data extraction.
MinVersionSFGA string
// DataSourceID may provide information which DataSaource ID should be
// used for importing data to GN database.
DataSourceID int
// DataSourceRelease provides release date of the imported data.
DataSourceRelease string
// DataSourceReleaseDate provides details when this version of
// data was released.
DataSourceReleaseDate string
// CacheDir keeps temporary directories for extracting and accessing
// SFGA data.
CacheDir string
// CacheDbDir is where SFGA database is downloaded.
CacheDbDir string
// DbDatabase is the name of the GN databsae, default is `gnames`.
DbDatabase string
// DbHost is the host of the GN database.
DbHost string
// DbUser is the user of the GN database with write privileges.
DbUser string
// DbPass is the password to the GN database for the given DbUser.
DbPass string
// JobsNum is the number of concurrent jobs to run.
JobsNum int
// BatchSize sets the size of batch for insert statements.
BatchSize int
}
type Option ¶
type Option func(*Config)
func OptDataSourceID ¶
func OptDataSourceRelease ¶
func OptDbDatabase ¶
func OptJobsNum ¶
Click to show internal directories.
Click to hide internal directories.